@@ -112,11 +112,17 @@ def ns_cfg(config):
     for feature, value in feature_list:
         d[feature] = value
     d.update(os.environ)
+
+    # here we try to do some type conversion for more intuitive usage.  Otherwise,
+    #    values like 35 are strings by default, making relational operations confusing.
+    # We also convert "True" and things like that to booleans.
     for k, v in config.variant.items():
         if k not in d:
             try:
                 d[k] = int(v)
             except (TypeError, ValueError):
+                if isinstance(v, string_types) and v.lower() in ('false', 'true'):
+                    v = v.lower() == 'true'
                 d[k] = v
     return d
 
@@ -1320,7 +1326,8 @@ class MetaData(object):
         return self.get_value('build/skip', False)
 
     def _get_contents(self, permit_undefined_jinja, allow_no_other_outputs=False,
-                      bypass_env_check=False, template_string=None, skip_build_id=False):
+                      bypass_env_check=False, template_string=None, skip_build_id=False,
+                      alt_name=None):
         '''
         Get the contents of our [meta.yaml|conda.yaml] file.
         If jinja is installed, then the template.render function is called
@@ -1371,6 +1378,10 @@ class MetaData(object):
                                              allow_no_other_outputs=allow_no_other_outputs,
                                              bypass_env_check=bypass_env_check,
                                              skip_build_id=skip_build_id))
+        # override PKG_NAME with custom value.  This gets used when an output needs to pretend
+        #   that it is top-level when getting the top-level recipe data.
+        if alt_name:
+            env.globals.update({'PKG_NAME': alt_name})
 
         # Future goal here.  Not supporting jinja2 on replaced sections right now.
 
@@ -1492,7 +1503,7 @@ class MetaData(object):
                             return vcs
         return None
 
-    def get_recipe_text(self, extract_pattern=None, force_top_level=False):
+    def get_recipe_text(self, extract_pattern=None, force_top_level=False, apply_selectors=True):
         parent_recipe = self.meta.get('extra', {}).get('parent_recipe', {})
         is_output = self.name() != parent_recipe.get('name') and parent_recipe.get('path')
         meta_path = self.meta_path or (os.path.join(parent_recipe['path'], 'meta.yaml')
@@ -1505,8 +1516,9 @@ class MetaData(object):
             from conda_build.render import output_yaml
             recipe_text = output_yaml(self)
         recipe_text = _filter_recipe_text(recipe_text, extract_pattern)
-        recipe_text = select_lines(recipe_text, ns_cfg(self.config),
-                                   variants_in_place=bool(self.config.variant))
+        if apply_selectors:
+            recipe_text = select_lines(recipe_text, ns_cfg(self.config),
+                                    variants_in_place=bool(self.config.variant))
         return recipe_text.rstrip()
 
     def extract_requirements_text(self, force_top_level=False):
@@ -1522,9 +1534,9 @@ class MetaData(object):
             f = r'(^requirements:.*?|(?<=-\sname:\s%s\s).*?requirements:.*?)(?=^\s*-\sname|^\s*test:|^\s*script:|^\s*extra:|^\s*about:|^outputs:|\Z)' % self.name()  # NOQA
         return self.get_recipe_text(f, force_top_level=force_top_level)
 
-    def extract_outputs_text(self):
+    def extract_outputs_text(self, apply_selectors=True):
         return self.get_recipe_text(r'(^outputs:.*?)(?=^test:|^extra:|^about:|\Z)',
-                                    force_top_level=True)
+                                    force_top_level=True, apply_selectors=apply_selectors)
 
     def extract_source_text(self):
         return self.get_recipe_text(
@@ -1533,10 +1545,10 @@ class MetaData(object):
     def extract_package_and_build_text(self):
         return self.get_recipe_text(r'(^.*?)(?=^requirements:|^test:|^extra:|^about:|^outputs:|\Z)')
 
-    def extract_single_output_text(self, output_name):
+    def extract_single_output_text(self, output_name, apply_selectors=True):
         # first, need to figure out which index in our list of outputs the name matches.
         #    We have to do this on rendered data, because templates can be used in output names
-        recipe_text = self.extract_outputs_text()
+        recipe_text = self.extract_outputs_text(apply_selectors=apply_selectors)
         output_matches = output_re.findall(recipe_text)
         try:
             output_index = [out.get('name') for out in
@@ -1872,7 +1884,7 @@ class MetaData(object):
         return {var for var in self.get_used_vars(force_top_level=force_top_level)
                 if var in self.get_loop_vars()}
 
-    def get_rendered_outputs_section(self):
+    def get_rendered_outputs_section(self, permit_undefined_jinja=False):
         extract_pattern = r'(.*)package:'
         template_string = '\n'.join((self.get_recipe_text(extract_pattern=extract_pattern,
                                                           force_top_level=True),
@@ -1880,20 +1892,21 @@ class MetaData(object):
                                     #    object (might be output)
                                     self.extract_outputs_text())).rstrip()
 
-        outputs = (yaml.safe_load(self._get_contents(permit_undefined_jinja=False,
+        outputs = (yaml.safe_load(self._get_contents(permit_undefined_jinja=permit_undefined_jinja,
                                                      template_string=template_string,
                                                      skip_build_id=True)) or {}).get('outputs', [])
         if not self.final:
             self.parse_until_resolved()
         return get_output_dicts_from_metadata(self, outputs=outputs)
 
-    def get_rendered_output(self, name):
+    def get_rendered_output(self, name, permit_undefined_jinja=False):
         """This is for obtaining the rendered, parsed, dictionary-object representation of an
         output. It's not useful for saying what variables are used. You need earlier, more raw
         versions of the metadata for that. It is useful, however, for getting updated, re-rendered
         contents of outputs."""
         output = None
-        for output_ in self.get_rendered_outputs_section():
+        for output_ in self.get_rendered_outputs_section(
+                permit_undefined_jinja=permit_undefined_jinja):
             if output_.get('name') == name:
                 output = output_
                 break
@@ -1931,12 +1944,13 @@ class MetaData(object):
         #   we promise to detect anything in meta.yaml, but not elsewhere.
         is_output = (not self.path and self.meta.get('extra', {}).get('parent_recipe'))
         if is_output and not force_top_level:
-            recipe_text = self.extract_single_output_text(self.name())
+            recipe_text = self.extract_single_output_text(self.name(), apply_selectors=False)
         else:
-            recipe_text = (self.get_recipe_text(force_top_level=force_top_level).replace(
-                                self.extract_outputs_text().strip(), '') +
-                           self.extract_single_output_text(self.name()))
-        reqs_re = re.compile(r"requirements:.+?(?=^\w|\Z|^\s+-\s(?:name|type))", flags=re.M | re.S)
+            recipe_text = (self.get_recipe_text(force_top_level=force_top_level,
+                                                apply_selectors=False).replace(
+                                self.extract_outputs_text(apply_selectors=False).strip(), '') +
+                           self.extract_single_output_text(self.name(), apply_selectors=False))
+        reqs_re = re.compile(r"requirements:.+?(?=^\w|\Z|^\s+-\s(?=name|type))", flags=re.M | re.S)
         recipe_text_without_requirements = reqs_re.sub('', recipe_text)
 
         all_used = variants.find_used_variables_in_text(self.config.variant, recipe_text)
@@ -1979,7 +1993,8 @@ class MetaData(object):
         return used_vars
 
     def _get_used_vars_output_script(self):
-        this_output = self.get_rendered_output(self.name()) or {}
+        this_output = self.get_rendered_output(self.name(),
+                                               permit_undefined_jinja=True) or {}
         used_vars = set()
         if 'script' in this_output:
             path = self.meta.get('extra', {}).get('parent_recipe', {}).get('path')
@@ -2013,7 +2028,15 @@ class MetaData(object):
         recipe_no_outputs = self.get_recipe_text(force_top_level=True).replace(
             self.extract_outputs_text(), "")
         top_no_outputs = {}
+        # because we're an output, calls to PKG_NAME used in the top-level
+        #    content will reflect our current name, not the top-level name. We
+        #    fix that here by replacing any PKG_NAME instances with the known
+        #    parent name
+        parent_recipe = self.meta.get('extra', {}).get('parent_recipe', {})
+        is_output = self.name() != parent_recipe.get('name') and parent_recipe.get('path')
+        alt_name = parent_recipe['name'] if is_output else None
         if recipe_no_outputs:
             top_no_outputs = yaml.safe_load(self._get_contents(False,
-                                                                template_string=recipe_no_outputs))
+                                                               template_string=recipe_no_outputs,
+                                                               alt_name=alt_name))
         return top_no_outputs or {}
