@@ -119,6 +119,7 @@ def hoist_single_extracted_folder(nested_folder):
     know exactly what that folder is called."""
     flist = os.listdir(nested_folder)
     parent = os.path.dirname(nested_folder)
+    # only hoist if the parent folder contains ONLY our nested folder
     nested_folders_to_remove = [nested_folder]
     for thing in flist:
         if not os.path.isdir(os.path.join(parent, thing)):
@@ -126,6 +127,11 @@ def hoist_single_extracted_folder(nested_folder):
         else:
             copy_into(os.path.join(nested_folder, thing), os.path.join(parent, thing))
             nested_folders_to_remove.append(os.path.join(nested_folder, thing))
+    # handle nested similar folder names
+    fn = os.path.basename(nested_folder)
+    if (os.path.join(nested_folder, fn) in nested_folders_to_remove and
+            nested_folder in nested_folders_to_remove):
+        nested_folders_to_remove.remove(nested_folder)
     for folder in nested_folders_to_remove:
         rm_rf(folder)
 
